@@ -15,7 +15,7 @@ Business::CINS - Verify CUSIP International Numbering System Numbers
   $cn = Business::CINS->new('392690QT', 1);
   $chk = $cn->check_digit;
   $cn->cins($cn->cins.$chk);
-  print $cn->is_valid ? "Looks good." : "Invalid: ", $Business::CINS::ERROR, "\n";
+  print $cn->is_valid ? "Looks good." : "Invalid: ", $cn->error, "\n";
 
 =head1 DESCRIPTION
 
@@ -38,7 +38,7 @@ Algorithm::LUHN::valid_chars('*',36, '@',37, '#',38);
 
 use vars qw($VERSION $ERROR);
 
-$VERSION = '0.03';
+$VERSION = '1.00';
 
 =head1 METHODS
 
@@ -162,6 +162,17 @@ sub is_valid {
   return $r;
 }
 
+=item error()
+
+If the CINS object is not valid (! is_valid()) it returns the reason it is 
+not valid. Otherwise returns undef.
+
+=cut
+sub error {
+  my $self = shift;
+  return $ERROR unless $self->is_valid;
+}
+
 =item check_digit()
 
 This method returns the checksum of the given object. If the CINS number of
@@ -234,4 +245,9 @@ Copyright (c) 2001 Tim Ayers. All rights reserved.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 SEE ALSO
+
+General information about CINS can be found at 
+http://http://www.cusip.com/cusip/intrnal.html.
+
 =cut
